package test.org.sersar.cayenne.dao.impl;

import java.util.List;

import org.seasar.extension.dataset.DataSet;
import org.seasar.extension.unit.S2TestCase;

import examples.cayenne.dao.EmployeeAutoDao;
import examples.cayenne.entity.Employee;

/**
 * @author Takahiro MATSUNAGA
 * @see S2TestCase
 */
public class EmployeeAutoDaoTest extends S2TestCase {

    private EmployeeAutoDao employeeDao_;

    /**
     * @param name
     */
    public EmployeeAutoDaoTest(String name) {
        super(name);
    }

    public static void main(String[] args) {
        junit.textui.TestRunner.run(EmployeeAutoDaoTest.class);
    }

    /* (Javadoc Ȃ)
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();

        include("examples/cayenne/dao/EmployeeAutoDao.dicon");
    }

    /* (Javadoc Ȃ)
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    public void testGetAllEmployee() {
//        readXlsWriteDb("Employee.xls");

        List employees = employeeDao_.getAllEmployee();

        DataSet expected = readXls("getAllEmployee.xls");
        assertEquals("1", expected, employees);
    }

    public void testGetAllEmployeeOrderByEname() {
        List employees = employeeDao_.getAllEmployeeOrderByEname();

        DataSet expected = readXls("getAllEmployeeOrderByEname.xls");
        assertEquals("1", expected, employees);
    }

    public void testGetEmployeeById() {
        Employee employee = employeeDao_.getEmployeeByEmpno(7369);

        DataSet expected = readXls("getEmployeeById.xls");
        assertEquals("1", expected, employee);
    }

    public void testGetEmployeeByEnameJob() {
        List employee = employeeDao_.getEmployeeByEnameJob("SMITH", "CLERK");

        DataSet expected = readXls("getEmployeeByEnameJob.xls");
        assertEquals("1", expected, employee);
    }

    public void testGetEmployeesBySal() {
        List employee = employeeDao_.getEmployeesBySal(1500, 2500);

        DataSet expected = readXls("getEmployeeBySal.xls");
        assertEquals("1", expected, employee);
    }

    public void testInsert() {
        Employee employee = new Employee();
        employee.setEmpno(new Integer(4));
        employee.setEname("XitL");
        employee.setJob("l");

        employeeDao_.insert(employee);

        List employees = employeeDao_.getAllEmployee();

        DataSet expected = readXls("insertEmployee.xls");
        assertEquals("1", expected, employees);
    }

    public void testUpdate() {
        Employee employee = new Employee();
        employee.setEmpno(new Integer(4));
        employee.setEname("[~");
        employee.setJob("dinot ͔nj");
//        employee.setMgr(null);
//        employee.setHiredate(null);
//        employee.setSal(null);
//        employee.setComm(null);
//        employee.setDeptno(null);

        employeeDao_.update(employee);

        List employees = employeeDao_.getAllEmployee();

        DataSet expected = readXls("updateEmployee.xls");
        assertEquals("1", expected, employees);
    }

    public void testDelete() {
        Employee employee = new Employee();
        employee.setEmpno(new Integer(4));

        employeeDao_.delete(employee);

        List employees = employeeDao_.getAllEmployee();

        DataSet expected = readXls("deleteEmployee.xls");
        assertEquals("1", expected, employees);
    }

}
